[jsonrpc-glib/jsonrpc-glib-3-28] client: fix invalid type propagation



commit 7fe93008b0cc4cd1c43611b6f6ceee0f2848dcc7
Author: Christian Hergert <chergert redhat com>
Date:   Tue May 29 14:46:59 2018 -0700

    client: fix invalid type propagation

 src/jsonrpc-client.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/src/jsonrpc-client.c b/src/jsonrpc-client.c
index 3ed244d..8a7eeb0 100644
--- a/src/jsonrpc-client.c
+++ b/src/jsonrpc-client.c
@@ -879,7 +879,7 @@ jsonrpc_client_call_sync_cb (GObject      *object,
  * @method: the name of the method to call
  * @params: (transfer none) (nullable): A #GVariant of parameters or %NULL
  * @cancellable: (nullable): A #GCancellable or %NULL
- * @return_value: (nullable) (out): A location for a #JsonNode.
+ * @return_value: (nullable) (out): A location for a #GVariant.
  *
  * Synchronously calls @method with @params on the remote peer.
  *
@@ -938,7 +938,7 @@ jsonrpc_client_call (JsonrpcClient  *self,
  * jsonrpc_client_call_async:
  * @self: A #JsonrpcClient
  * @method: the name of the method to call
  * @params: (transfer none) (nullable): A #JsonNode of parameters or %NULL
  * @cancellable: (nullable): A #GCancellable or %NULL
  * @callback: a callback to executed upon completion
  * @user_data: user data for @callback
@@ -1019,7 +1019,7 @@ jsonrpc_client_call_async (JsonrpcClient       *self,
  * jsonrpc_client_call_finish:
  * @self: A #JsonrpcClient.
  * @result: A #GAsyncResult provided to the callback in jsonrpc_client_call_async()
  * @return_value: (out) (nullable): A location for a #JsonNode or %NULL
  * @error: a location for a #GError or %NULL
  *
  * Completes an asynchronous call to jsonrpc_client_call_async().
@@ -1034,7 +1034,7 @@ jsonrpc_client_call_finish (JsonrpcClient  *self,
                             GVariant      **return_value,
                             GError        **error)
 {
-  g_autoptr(JsonNode) local_return_value = NULL;
+  g_autoptr(GVariant) local_return_value = NULL;
   gboolean ret;
 
   g_return_val_if_fail (JSONRPC_IS_CLIENT (self), FALSE);
@@ -938,7 +938,7 @@ jsonrpc_client_call (JsonrpcClient  *self,
  * @self: A #JsonrpcClient
  * @method: the name of the method to call
- * @params: (transfer none) (nullable): A #JsonNode of parameters or %NULL
+ * @params: (transfer none) (nullable): A #GVariant of parameters or %NULL
  * @cancellable: (nullable): A #GCancellable or %NULL
  * @callback: a callback to executed upon completion
@@ -1019,7 +1019,7 @@ jsonrpc_client_call_async (JsonrpcClient       *self,
  * @self: A #JsonrpcClient.
  * @result: A #GAsyncResult provided to the callback in jsonrpc_client_call_async()
- * @return_value: (out) (nullable): A location for a #JsonNode or %NULL
+ * @return_value: (out) (nullable): A location for a #GVariant or %NULL
  * @error: a location for a #GError or %NULL
  *


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]